﻿© 2002 Fluke Corporation, All rights reserved               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Yok DL7100 Record Reading IEEE
DATE:                  2002-08-23
AUTHOR:                MSD
REVISION:              $Revision: 1.2 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       2
NUMBER OF LINES:       158
=============================================================================
#
# Source:          Quality Inspection Standards : DL7100 Digital Oscilloscope
#                  Part Number: QIS701410
#                  Revision number: 1st Edition(1999.9)
#
# Source Author:   Yokogawa
#
# Compatibility:   MET/CAL 6.11A or later
#
# Subprocedures:   Sub Wait for Operation Complete (OPC) IEEE SCPI
#
# Required Files:  none
#
# The Procedure was tested using:
#
#                  Model No       DL7100
#                  Serial No      12V918531J
#
# System Specifications:
#   TUR calculation is based on specification interval of the accuracy file.
#
# THE COPYRIGHT IN THIS PROCEDURE IS OWNED BY FLUKE PRECISION MEASUREMENT
# LIMITED. THE TERMS AND CONDITIONS OF ITS USE ARE DESCRIBED IN THE
# LICENSE YOU ACCEPTED WHEN YOU INSTALLED THE METCAL SOFTWARE.
#
# Fluke makes no warranty, expressed or implied, as to the fitness
# or suitability of this procedure in the customer's application.
#
#
# System Specifications:
#   TUR calculation is based on specification interval of the accuracy file.
#   The default 9500A accuracy file contains 90 day specs.
#
# Overview:
#   This procedure is written to verify the operation of the Yok DL7100
#   Oscilloscope. This procedure performs a "closed-loop" verification
#   with a minimum of operater intervention.  The following documentation
#   lists the global registers used and subprocedures called.
#
# NUMERIC REGISTERS USED:
#
#   M[10]
#     This register is used in the status check subprocedure to
#     set watchdog timer in the event the oscillscope does not respond to a
#     status command.   THIS VARIABLE IS SOMETIMES USED IN THE MAIN PROCEDURE
#     as a Watchdog timer also.
#
#   M[11]
#     This register is used to store the value of MEM
#
#   M[12]
#     This register is used to store the value of MEM1
#
#   M[17]
#     This register is used to store the desired resolution of a measurement.
#     This value is then passed to the status check subprocedure for
#     calculations.
#
#   MEM2
#     This register is used to pass commands to the status check subprocedure.
#     This is used with the READING Flag.  The benefit of using this technique
#     is the ability to reduce the amout of dedicated programs.
#
#   M[100]
#     This register specifies which channel of the oscilloscope
#     is currently in use.
#       M[100] = 1 means Channel 1
#       M[100] = 2 means Channel 2
#       M[100] = 3 means Channel 3
#       M[100] = 4 means Channel 4
#
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# Backup MEM and MEM1
  1.001  MATH         M[11] = MEM
  1.002  MATH         M[12] = MEM1
# ******************** RECORD READING ********************

# Reset the watchdog counter
  1.003  LABEL        RECORD_READING
  1.004  MATH         M[10] = 0

  1.005  LABEL        CHECK_FOR_STABLE_READING
# We will go through this loop 50 times.  If there is not a good reading
# then we will warn the operator

  1.006  MATH         M[10] = M[10] + 1
  1.007  JMPL         UNSTABLE_READING             M[10] > 50

  1.008  LABEL        READING1
  1.009  CALL         Sub Wait for Operation Complete (OPC) IEEE SCPI
  1.010  JMPL         RESTORE_MEM_AND_MEM1         M[89] < 1
  1.011  IEEE         :MEAS:CHAN[M100][SREG5][I]
  1.012  MATH         M[14] = MEM
  1.013  HEAD         Channel Reading = [MEM]
  1.014  IEEE         [D350]

  1.015  LABEL        READING2
  1.016  CALL         Sub Wait for Operation Complete (OPC) IEEE SCPI
  1.017  JMPL         RESTORE_MEM_AND_MEM1         M[89] < 1
  1.018  IEEE         :MEAS:CHAN[M100][SREG5][I]
  1.019  MATH         M[15] = MEM
  1.020  HEAD         Channel Reading = [MEM]
  1.021  IEEE         [D350]

  1.022  LABEL        READING3
  1.023  CALL         Sub Wait for Operation Complete (OPC) IEEE SCPI
  1.024  JMPL         RESTORE_MEM_AND_MEM1         M[89] < 1
  1.025  IEEE         :MEAS:CHAN[M100][SREG5][I]
  1.026  HEAD         Channel Reading = [MEM]
  1.027  MATH         M[16] = MEM

  1.028  MATH         M[18] = MIN (14, 16)
  1.029  MATH         M[19] = MAX (14, 16)

# We picked a value of 5 times the resolution of the
# measurement to determine a stable reading.  Other
# factors like noise or condition of the scope will
# have a factor in this.

  1.030  MATH         M[20] = ABS(M[18] - M[19])
  1.031  JMPL         CHECK_FOR_STABLE_READING   M[20] > (5.0 * M[17])
  1.032  JMPL         TAKE_READING

  1.033  LABEL        UNSTABLE_READING
  1.034  OPBR         The Scope has encountered an unstable value.
  1.034  OPBR         Do you wish to take more readings?
  1.035  JMPL         RECORD_READING             MEM1 > 0

# Take one more reading and use it
  1.036  LABEL        TAKE_READING
  1.037  CALL         Sub Wait for Operation Complete (OPC) IEEE SCPI
  1.038  JMPL         RESTORE_MEM_AND_MEM1         M[89] < 1
  1.039  IEEE         :MEAS:CHAN[M100][SREG5][I]
  1.040  HEAD         Channel Reading = [MEM]
# Note, MEM is restored from M[11] at bottom of this procedure.
  1.041  MATH         M[11] = MEM
  1.042  JMPL         RESTORE_MEM_AND_MEM1

  1.043  EVAL   dummy

# ******************** END OF PROCEDURES ********************

  2.001  LABEL        RESTORE_MEM_AND_MEM1
  2.002  MATH         MEM = M[11]
  2.003  MATH         MEM1 = M[12]
  2.004  END
